@@ -10,6 +10,31 @@ import threading
 from typing import List
 from datetime import datetime
 from mw_python_sdk.core import DatasetFile
+import time
+from functools import wraps
+
+
+# Rate-limiting decorator
+def rate_limited(rate_limit_seconds: float):
+    def decorator(func):
+        last_called = [0.0]  # We store this as a mutable to track the last call time
+
+        @wraps(func)
+        def wrapper(filename, seen_so_far, size, *args, **kwargs):
+            current_time = time.time()
+            time_since_last_call = current_time - last_called[0]
+
+            # Always print if we've reached the end (seen_so_far == size)
+            if seen_so_far == size or time_since_last_call >= rate_limit_seconds:
+                last_called[0] = current_time
+                return func(filename, seen_so_far, size, *args, **kwargs)
+            # Skip if within the rate limit
+            return None
+
+        return wrapper
+
+    return decorator
+
 
 # Create a logger for your library
 logger = logging.getLogger(__name__)
@@ -76,10 +101,11 @@ def sizeof_fmt(num, suffix="B"):
     return f"{num:.1f}Yi{suffix}"
 
 
+@rate_limited(0.01)  # 100 calls per second
 def print_percent(filename: str, seen_so_far: float, size: float):
     percentage = (seen_so_far / size) * 100
     sys.stdout.write(
-        "\r %s %s / %s  (%.2f%%)    "
+        "\r%s %s / %s  (%.2f%%)    "
         % (
             filename,
             sizeof_fmt(seen_so_far),
